clear all, clc

%% Load Data
% To plot the data used in Fig. 5, select data from
% Adhesion_Preliminary_20220718_1_1 up to Adhesion_Preliminary_20220718_3_10

FolderName  = 'C:\xxxx\xxxx\xxxx\Fig 4 & 5'; %Insert Directory
FileNames = uigetfile('*.csv','Select One or More Files', 'MultiSelect', 'on', FolderName);

%% pre
fignr = 1;

%% Use ReadData function to convert the data

if isa(FileNames,'char') == 1
    FileNames = {FileNames}; %Further script only works if FileNames is of 'cell' type. If only one file is selected FileNames will become a 'char' and must first be converted
end

for k = 1:length(FileNames)
    
    fn = char(FileNames(k)); %Make a 'char' from the 'cell' from the FileName in the current loop
    TestData.(fn(1:end-4)) = ReadData(FolderName, fn); % function to alter the testdata
    PC_comp = TestData.(fn(1:end-4)).PC_comp; %This is the index of the datapoint where the compression phase switches to the relaxation phase 
    PC_rlx = TestData.(fn(1:end-4)).PC_rlx; %This is the index of the datapoint where the relaxation phase switches to the tension phase
    
    %% Apply Filter
    
    TestData.(fn(1:end-4)).NormalForce(1:PC_comp) = smoothdata(TestData.(fn(1:end-4)).NormalForce(1:PC_comp),'gaussian',20); %Moving average filter over 5 datapoints
    TestData.(fn(1:end-4)).NormalForce(PC_comp:PC_rlx) = smoothdata(TestData.(fn(1:end-4)).NormalForce(PC_comp:PC_rlx),'gaussian',3); %Moving average filter over 5 datapoints
    TestData.(fn(1:end-4)).NormalForce(PC_rlx:end) = smoothdata(TestData.(fn(1:end-4)).NormalForce(PC_rlx:end),'gaussian',50); %Moving average filter over 5 datapoints
    TestData.(fn(1:end-4)).gap = smoothdata(TestData.(fn(1:end-4)).gap,'gaussian',10); %Moving average filter over 5 datapoints
    
    % Find relevant parameters
    TestData.(fn(1:end-4)).F_max = -min(TestData.(fn(1:end-4)).NormalForce); %Maximum Force
    TestData.(fn(1:end-4)).W_adh = trapz(TestData.(fn(1:end-4)).gap_shifted(PC_rlx:end),-TestData.(fn(1:end-4)).NormalForce(PC_rlx:end)); %Work of adhesion 
    TestData.(fn(1:end-4)).Compression_stdev = std(TestData.(fn(1:end-4)).NormalForce(1:PC_comp)); %standard deviation of force control in compression phase
    TestData.(fn(1:end-4)).Compression_mean = mean(TestData.(fn(1:end-4)).NormalForce(1:PC_comp)); %mean of force control in compression phase
    TestData.(fn(1:end-4)).velocity_mean = mean(TestData.(fn(1:end-4)).velocity(PC_rlx:end)); %mean of the displacement rate 
    TestData.(fn(1:end-4)).thickness = min(TestData.(fn(1:end-4)).gap);
    
    % List relevant parameters (to display later on in a table)
    F_max(k)         = TestData.(fn(1:end-4)).F_max;
    W_adh(k)         = TestData.(fn(1:end-4)).W_adh; 
    F_compression(k) = TestData.(fn(1:end-4)).F_compression;
    F_stdev(k)       = TestData.(fn(1:end-4)).Compression_stdev;
    F_mean(k)        = TestData.(fn(1:end-4)).Compression_mean;
    disp_rate(k)     = TestData.(fn(1:end-4)).velocity_mean; 
    Specimens(k)     = TestData.(fn(1:end-4)).Specimen;
    thickness(k)     = TestData.(fn(1:end-4)).thickness;
    sigma(k)         = F_max(k)./(18e-3*18e-3)/10^6; %Max tension to overcome [MPa]
    
end
%% Display table with relevant output 

T = table(FileNames',-F_compression', ceil(-disp_rate'/10)*10, F_mean', F_stdev', F_max', W_adh');
T.Properties.VariableNames = {'Test','F_c_input [N]', 'input disp rate [umm/sec]' 'F_c_mean [N]', 'F_c_stdev', 'F_max [N]', 'W_adh [mJ]'}

%% Plot used in fig 5
% This section only works if all data is selected (see code line 4&5)
F_max = reshape(F_max,10,3)';
W_adh = reshape(W_adh,10,3)'; 

for k = 1:10
    F_max_normalized(:,k) = F_max(:,k)./F_max(:,1) ;
    W_adh_normalized(:,k) = W_adh(:,k)./W_adh(:,1) ; 
end

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Figures in ESAFORM Papers
figure(fignr),clf(fignr), hold on 
errorbar(1:10, mean(F_max), std(F_max),'k', 'LineWidth',1) 
grid on 
ylabel('F_{max} [N]')

width = 19; %cm
set(gcf,'units','centimeters','position',[5,5,width/2.1,0.4*width])
axis([0 11 0 20])
ax = gca;

xlabel('Number of tests conducted on the same specimen')
set(gca,'XTickLabel',get(gca,'XTickLabel'),'FontName','Times New Roman','FontSize',12)
hold off 
fignr = fignr + 1;

figure(fignr),clf(fignr),hold on 
set(gcf,'units','centimeters','position',[15,5,width/2.1,0.4*width])
plot(1:10,F_max_normalized(1,:),'*k','LineWidth',0.8)
plot(1:10,F_max_normalized(2,:),'ok','LineWidth',0.8)
plot(1:10,F_max_normalized(3,:),'squarek','LineWidth',0.8)
set(gca,'XTickLabel',get(gca,'XTickLabel'),'FontName','Times New Roman','FontSize',12)
xlabel('Number of tests conducted on the same specimen')
ylabel('F_{max} (normalized)')
grid on
legend('set 1','set 2','set 3','Location','NorthWest')