function [TestData] = ReadData(FolderName, fn)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% This function can be used to rearrange data from rheometer          %%%
%%% experiments to convert it into a MATLAB structure. Note: the        %%%
%%% function only works with .csv files that have a comma as a decimal  %%%
%%% separator.                                                          %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Read the data and convert into a matrix
A = readmatrix(fullfile(FolderName,fn),"DecimalSeparator",",",'NumHeaderLines',0);

Specimen    = A(1,6);   

%% First Phase 
PC_comp        = A(1,3); %PC=Phase change) Index at which the first phase changes to the 2nd phase

% Delete first 4 rows.
A(1:4,:) = []; 

PC_rlx    = A(PC_comp+1,3); 
PC_rlx    = PC_comp+PC_rlx;

%Delete rows between compression and relaxation phases
A(PC_comp+1:PC_comp+4,:) = [];

%connect index
A(PC_comp+1:PC_rlx,2) = A(PC_comp+1:PC_rlx,2) + A(PC_comp,2);

%% Second Phase
PSI3 = A(PC_rlx+2,3);
%Delete rows between compression and relaxation phases
A(PC_rlx+1:PC_rlx+5,:) = []; 


%Delete side column
A(:,1) = []; 

%Connect indices and time 
A(PC_rlx+1:end,1) = A(PC_rlx+1:end,1)+A(PC_rlx,1); %index
A(PC_rlx+1:end,2) = A(PC_rlx+1:end,2)+A(PC_rlx,2); %time
%Define vector parameters
index       = A(:,1);
time        = A(:,2); 
NormalForce = A(:,3); 
velocity    = A(:,4);
gap         = A(:,5);
Temperature = A(:,7);

% Check if some data is invalid; if so, interpolate 
[index, time, NormalForce, gap, Temperature] = InterpolateInvalidData(index, time, NormalForce, velocity, gap, Temperature);

% Define vector where the gap starts at 0 mm as soon as tensile force is applied:
index_positive_force = min(find(NormalForce<0));% + PC_rlx;
index_positive_force = max([index_positive_force PC_rlx]);

gap_shifted = gap - gap(index_positive_force);

%Output scalar input parameters
fs_compression  = 1/time(1);
fs_tension      = 1/((time(PC_comp+2)-time(PC_comp+1)));
F_compression   = round(mean(NormalForce(1:PC_comp)));
v_tension       = -round(mean(velocity(PC_comp+1:end)));

%Rearrange all data into structure. 1:end-4 to delete the '.csv' of the
%filename
TestData.Specimen = Specimen;
TestData.index = index;
TestData.time = time;
TestData.NormalForce = NormalForce;
TestData.velocity = velocity;
TestData.gap = gap;
TestData.gap_shifted = gap_shifted;
TestData.fs_compression = fs_compression;
TestData.fs_tension = fs_tension;
TestData.F_compression = F_compression;
TestData.v_tension = v_tension;
TestData.PC_comp = PC_comp;
TestData.PC_rlx = PC_rlx;
TestData.IndexPositiveForce = index_positive_force;
TestData.Temperature = Temperature;

end

