clear all, clc 

%% Load Data
FolderName  = 'C:\xxx\xxx\xxx\Fig 6 & Table 2'; %Load folder, Fill in correct directory!
FileNames = uigetfile('*.csv','Select One or More Files', 'MultiSelect', 'on', FolderName);

%% pre stuff
fignr = 1;
figure(fignr), clf(fignr);

%% Use ReadData function to convert the data

if isa(FileNames,'char') == 1
    FileNames = {FileNames}; %Further script only works if FileNames is of 'cell' type. If only one file is selected FileNames will become a 'char' and must first be converted
end


for k = 1:length(FileNames)
    
    fn = char(FileNames(k)); %Make a 'char' from the 'cell' from the FileName in the current loop
     
    TestData.(fn(1:end-4)) = ReadData(FolderName, fn); % function to alter the testdata
    
    PC_comp = TestData.(fn(1:end-4)).PC_comp; %This is the index of the datapoint where the compression phase switches to the relaxation phase 
    PC_rlx = TestData.(fn(1:end-4)).PC_rlx; %This is the index of the datapoint where the relaxation phase switches to the tension phase
    
    %% Apply Filter
    
    TestData.(fn(1:end-4)).NormalForce(1:PC_comp) = smoothdata(TestData.(fn(1:end-4)).NormalForce(1:PC_comp),'gaussian',20); %Moving average filter over 5 datapoints
    TestData.(fn(1:end-4)).NormalForce(PC_comp:PC_rlx) = smoothdata(TestData.(fn(1:end-4)).NormalForce(PC_comp:PC_rlx),'gaussian',3); %Moving average filter over 5 datapoints
    TestData.(fn(1:end-4)).NormalForce(PC_rlx:end) = smoothdata(TestData.(fn(1:end-4)).NormalForce(PC_rlx:end),'gaussian',50); %Gaussian filter over 50 datapoints
    TestData.(fn(1:end-4)).gap = smoothdata(TestData.(fn(1:end-4)).gap,'gaussian',10); %Moving average filter over 5 datapoints
    
    
    % Find relevant parameters
    TestData.(fn(1:end-4)).F_max = -min(TestData.(fn(1:end-4)).NormalForce); %Maximum Force
    TestData.(fn(1:end-4)).W_adh = trapz(TestData.(fn(1:end-4)).gap_shifted(PC_rlx:end),-TestData.(fn(1:end-4)).NormalForce(PC_rlx:end)); %Work of adhesion 
    TestData.(fn(1:end-4)).Compression_stdev = std(TestData.(fn(1:end-4)).NormalForce(1:PC_comp)); %standard deviation of force control in compression phase
    TestData.(fn(1:end-4)).Compression_mean = mean(TestData.(fn(1:end-4)).NormalForce(1:PC_comp)); %mean of force control in compression phase
    TestData.(fn(1:end-4)).velocity_mean = mean(TestData.(fn(1:end-4)).velocity(PC_rlx:end)); %mean of the displacement rate 
    TestData.(fn(1:end-4)).thickness = min(TestData.(fn(1:end-4)).gap);
    
    % List relevant parameters (to display later on in a table)
    F_max(k)         = TestData.(fn(1:end-4)).F_max;
    W_adh(k)         = TestData.(fn(1:end-4)).W_adh; 
    F_compression(k) = TestData.(fn(1:end-4)).F_compression;
    F_stdev(k)       = TestData.(fn(1:end-4)).Compression_stdev;
    F_mean(k)        = TestData.(fn(1:end-4)).Compression_mean;
    disp_rate(k)     = TestData.(fn(1:end-4)).velocity_mean; 
    t_compression(k) = TestData.(fn(1:end-4)).t_compression;
    thickness(k)     = TestData.(fn(1:end-4)).thickness;
    sigma(k)         = F_max(k)./(20e-3*20e-3)/10^6; %Max tension to overcome [MPa]
    
    % plot
   
    hold on
    plot(TestData.(fn(1:end-4)).gap_shifted(TestData.(fn(1:end-4)).PC_rlx:end),-TestData.(fn(1:end-4)).NormalForce(TestData.(fn(1:end-4)).PC_rlx:end),'LineWidth',1);
    %plot(TestData.(fn(1:end-4)).gap(TestData.(fn(1:end-4)).PC_rlx:end),-TestData.(fn(1:end-4)).NormalForce(TestData.(fn(1:end-4)).PC_rlx:end),'LineWidth',1);
    
    %Determine legend info per plot
    LegendInfo{k} = (fn(1:end-4));
end


%% Clean up plot

xlabel('displacement [mm]'); ylabel('Normal Force [N]'); grid on
legend(LegendInfo,'Location','SouthEast','Interpreter','none')
axis([0 0.6 0 max(F_max)*1.5])

hold off 
fignr = fignr+1;
%% Display table with relevant output 

T = table(FileNames',-F_compression', t_compression', ceil(-disp_rate'/10)*10, F_mean', F_stdev', F_max', W_adh');
T.Properties.VariableNames = {'Test','F_c_input [N]', 't_c_input [sec]', 'input disp rate [umm/sec]' 'F_c_mean [N]', 'F_c_stdev', 'F_max [N]', 'W_adh [mJ]'}

%% Plot the mean of all selected data with error bars

% PlotMean(FileNames,TestData,fignr,PC_rlx)
% fignr = fignr+1;

%% Plot Bar Graph 
% PlotBar(FileNames,T,fignr)
% fignr = fignr+1;

%% Plot data
% figure(fignr),clf(fignr), hold on 
% 
% plot(t_compression, F_max,'*r')
% 



