function[index, time, NormalForce, gap, Temperature] = InterpolateInvalidData(index, time, NormalForce, velocity, gap, Temperature)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Sometimes it happens that the rheometer does not log very well. When %%%
%%% this happens, there are snippets of information missing, filled with %%%
%%% NaN values. This function interpolates the values from these         %%%
%%% snippets. For example, if the rheometer output is                    %%%
%%% [1 2 NaN NaN NaN 3 4], the function will replace this with           %%%     
%%% [1 2 2.25 2.5 2.75 3 4]                                              %%%                                            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% if a value is NaN, it will get value 1. if not, value is 0
indexNaN    = isnan(index);
if mean(indexNaN) == 0 %return if there are no NaN values
    return
end

% Preallocating
NaNIndices  = [0];
counter     =   1;

%Define a matrix with two columns per range of NaN indices. First row
%indicates the starting index of a NaN sequence. Second row indicates the index
%of the end of a NaN sequence
for k = 1:length(index)-1
    
    if indexNaN(k+1) == indexNaN(k)+1 
        NaNIndices(counter,1) = index(k)+1;
        
    elseif indexNaN(k+1) == indexNaN(k)-1 && indexNaN(k) == 1 
        NaNIndices(counter,2) = index(k+1)-1;
        counter = counter+1;
    end
    
end

for k = 1:size(NaNIndices,1)
    % Define first and last indices of a series of NaN entries
    Begin = NaNIndices(k,1);
    End = NaNIndices(k,2);
    
    Size = End-Begin+1; %Amount of samples in the NanSeries
    
    %create a replacement vector for the NaN sequence for every variable 
    Interpolated_gap            = linspace(gap(Begin-1),gap(End+1),Size+2);
    Interpolated_time           = linspace(time(Begin-1),time(End+1),Size+2);
    Interpolated_NormalForce    = linspace(NormalForce(Begin-1),NormalForce(End+1),Size+2);
    Interpolated_velocity       = linspace(velocity(Begin-1),velocity(End+1),Size+2);
    Interpolated_Temperature    = linspace(Temperature(Begin-1),Temperature(End+1),Size+2);
    
    %Replace the NaN sequence with the replacement vector
    gap(Begin:End) = Interpolated_gap(2:end-1)';
    time(Begin:End) = Interpolated_time(2:end-1)';
    NormalForce(Begin:End) = Interpolated_NormalForce(2:end-1)';
    velocity(Begin:End) = Interpolated_velocity(2:end-1)';
    Temperature(Begin:End) = Interpolated_Temperature(2:end-1)';
end

end
